@@ -7,7 +7,8 @@
   /* NQS license information */
 #include <nqs_generic/debug.h>
   /* debugging information */
-
+#include <nqs_generic/proto.h>
+  /* ANSI C prototypes */
 #include <nqs_db/nqs_db.h>
   /* prototype for fetchpwuid() */
 
