@@ -7,6 +7,8 @@
   /* NQS license information */
 #include <nqs_generic/debug.h>
   /* debugging support */
+#include <nqs_generic/proto.h>
+  /* ANSI C prototypes */
 
 #include <unistd.h>
 
